@@ -9,17 +9,17 @@ use warnings;
 use strict;
 
 use utf8;
-#use POSIX qw/setlocale/;
-#setlocale(&POSIX::LC_ALL, "en_US");
 use locale;
 
+
+
 use Time::HiRes;
 use Lingua::PTD::Dumper;
 use Lingua::PTD::BzDmp;
 use Lingua::PTD::XzDmp;
 use Lingua::PTD::SQLite;
 
-our $VERSION = '1.03';
+our $VERSION = '1.04';
 
 =encoding UTF-8
 
@@ -131,7 +131,7 @@ sub dump {
     print "\$a = {\n";
     $self->downtr(
                   sub {
-                      my ($w,$c,%t) = @_;			
+                      my ($w,$c,%t) = @_;
                       printf "  '%s' => {\n", _protect_quotes($w);
                       printf "      count => %d,\n", $c;
                       printf "      trans => {\n";
@@ -723,6 +723,10 @@ sub lowercase {
                       if ($w =~ /[[:upper:]]/) {
                           my $lw = lc $w;
 
+                          open X, ">>:utf8", "log";
+                          print X "WAS $w, IS $lw\n";
+                          close X;
+
                           my %ot = $self->transHash($lw);
                           if (%ot) {
                               my ($c1, $c2) = ($c, $self->count($lw));
